==> ejc-settlementmanage-impl-3.0.0-20220425.073851-9-sources.jar: com/ejianc/business/settlementmanage/vo/TurnoverLeaseSetDetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 周转租赁结算-子表
 * 
 * @author generator
 * 
 */
public class TurnoverLeaseSetDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.String sort; // 序号
    private java.lang.String months; // 月份
    private java.math.BigDecimal intaxLeasePrice; // 租赁合价(含税)
    private java.math.BigDecimal extaxLeasePrice; // 租赁合价(除税)
    private java.math.BigDecimal intaxCompensationPayable; // 赔偿金额(含税)
    private java.math.BigDecimal extaxCompensationPayable; // 赔偿金额(除税)
    private java.math.BigDecimal intaxRepair; // 修理费等其它费用(含税)
    private java.math.BigDecimal extaxRepair; // 修理费等其它费用(除税)
    private java.math.BigDecimal intaxMonthlySettlementAmount; // 月度结算费用(含税)
    private java.math.BigDecimal extaxMonthlySettlementAmount; // 月度结算费用(除税)
    private java.lang.String remarks; // 备注
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 月份
     */
    public java.lang.String getMonths() {
        return months;
    }

    /**
     * 月份
     */
    public void setMonths(java.lang.String months) {
        this.months = months;
    }
    /**
     * 租赁合价(含税)
     */
    public java.math.BigDecimal getIntaxLeasePrice() {
        return intaxLeasePrice;
    }

    /**
     * 租赁合价(含税)
     */
    public void setIntaxLeasePrice(java.math.BigDecimal intaxLeasePrice) {
        this.intaxLeasePrice = intaxLeasePrice;
    }
    /**
     * 租赁合价(除税)
     */
    public java.math.BigDecimal getExtaxLeasePrice() {
        return extaxLeasePrice;
    }

    /**
     * 租赁合价(除税)
     */
    public void setExtaxLeasePrice(java.math.BigDecimal extaxLeasePrice) {
        this.extaxLeasePrice = extaxLeasePrice;
    }
    /**
     * 赔偿金额(含税)
     */
    public java.math.BigDecimal getIntaxCompensationPayable() {
        return intaxCompensationPayable;
    }

    /**
     * 赔偿金额(含税)
     */
    public void setIntaxCompensationPayable(java.math.BigDecimal intaxCompensationPayable) {
        this.intaxCompensationPayable = intaxCompensationPayable;
    }
    /**
     * 赔偿金额(除税)
     */
    public java.math.BigDecimal getExtaxCompensationPayable() {
        return extaxCompensationPayable;
    }

    /**
     * 赔偿金额(除税)
     */
    public void setExtaxCompensationPayable(java.math.BigDecimal extaxCompensationPayable) {
        this.extaxCompensationPayable = extaxCompensationPayable;
    }
    /**
     * 修理费等其它费用(含税)
     */
    public java.math.BigDecimal getIntaxRepair() {
        return intaxRepair;
    }

    /**
     * 修理费等其它费用(含税)
     */
    public void setIntaxRepair(java.math.BigDecimal intaxRepair) {
        this.intaxRepair = intaxRepair;
    }
    /**
     * 修理费等其它费用(除税)
     */
    public java.math.BigDecimal getExtaxRepair() {
        return extaxRepair;
    }

    /**
     * 修理费等其它费用(除税)
     */
    public void setExtaxRepair(java.math.BigDecimal extaxRepair) {
        this.extaxRepair = extaxRepair;
    }
    /**
     * 月度结算费用(含税)
     */
    public java.math.BigDecimal getIntaxMonthlySettlementAmount() {
        return intaxMonthlySettlementAmount;
    }

    /**
     * 月度结算费用(含税)
     */
    public void setIntaxMonthlySettlementAmount(java.math.BigDecimal intaxMonthlySettlementAmount) {
        this.intaxMonthlySettlementAmount = intaxMonthlySettlementAmount;
    }
    /**
     * 月度结算费用(除税)
     */
    public java.math.BigDecimal getExtaxMonthlySettlementAmount() {
        return extaxMonthlySettlementAmount;
    }

    /**
     * 月度结算费用(除税)
     */
    public void setExtaxMonthlySettlementAmount(java.math.BigDecimal extaxMonthlySettlementAmount) {
        this.extaxMonthlySettlementAmount = extaxMonthlySettlementAmount;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-settlementmanage-impl-3.0.0-20220902.041051-56-sources.jar: com/ejianc/business/settlementmanage/vo/TurnoverLeaseSetDetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 周转租赁结算-子表
 * 
 * @author generator
 * 
 */
public class TurnoverLeaseSetDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.String sort; // 序号
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy/MM", timezone = "GMT+8")
    private java.util.Date months;  // 月份
    private java.math.BigDecimal intaxLeasePrice; // 租赁合价(含税)
    private java.math.BigDecimal extaxLeasePrice; // 租赁合价(除税)
    private java.math.BigDecimal intaxCompensationPayable; // 赔偿金额(含税)
    private java.math.BigDecimal extaxCompensationPayable; // 赔偿金额(除税)
    private java.math.BigDecimal intaxRepair; // 修理费等其它费用(含税)
    private java.math.BigDecimal extaxRepair; // 修理费等其它费用(除税)
    private java.math.BigDecimal intaxMonthlySettlementAmount; // 月度结算费用(含税)
    private java.math.BigDecimal extaxMonthlySettlementAmount; // 月度结算费用(除税)
    private java.lang.String remarks; // 备注
    private java.lang.String errorMsg;//错误信息
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy/MM", timezone = "GMT+8")
    private java.lang.String monthsShow;

    public String getMonthsShow() {
        return monthsShow;
    }

    public void setMonthsShow(String monthsShow) {
        this.monthsShow = monthsShow;
    }
    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 月份
     */
    public java.util.Date getMonths() {
        return months;
    }

    /**
     * 月份
     */
    public void setMonths(java.util.Date months) {
        this.months = months;
    }
    /**
     * 租赁合价(含税)
     */
    public java.math.BigDecimal getIntaxLeasePrice() {
        return intaxLeasePrice;
    }

    /**
     * 租赁合价(含税)
     */
    public void setIntaxLeasePrice(java.math.BigDecimal intaxLeasePrice) {
        this.intaxLeasePrice = intaxLeasePrice;
    }
    /**
     * 租赁合价(除税)
     */
    public java.math.BigDecimal getExtaxLeasePrice() {
        return extaxLeasePrice;
    }

    /**
     * 租赁合价(除税)
     */
    public void setExtaxLeasePrice(java.math.BigDecimal extaxLeasePrice) {
        this.extaxLeasePrice = extaxLeasePrice;
    }
    /**
     * 赔偿金额(含税)
     */
    public java.math.BigDecimal getIntaxCompensationPayable() {
        return intaxCompensationPayable;
    }

    /**
     * 赔偿金额(含税)
     */
    public void setIntaxCompensationPayable(java.math.BigDecimal intaxCompensationPayable) {
        this.intaxCompensationPayable = intaxCompensationPayable;
    }
    /**
     * 赔偿金额(除税)
     */
    public java.math.BigDecimal getExtaxCompensationPayable() {
        return extaxCompensationPayable;
    }

    /**
     * 赔偿金额(除税)
     */
    public void setExtaxCompensationPayable(java.math.BigDecimal extaxCompensationPayable) {
        this.extaxCompensationPayable = extaxCompensationPayable;
    }
    /**
     * 修理费等其它费用(含税)
     */
    public java.math.BigDecimal getIntaxRepair() {
        return intaxRepair;
    }

    /**
     * 修理费等其它费用(含税)
     */
    public void setIntaxRepair(java.math.BigDecimal intaxRepair) {
        this.intaxRepair = intaxRepair;
    }
    /**
     * 修理费等其它费用(除税)
     */
    public java.math.BigDecimal getExtaxRepair() {
        return extaxRepair;
    }

    /**
     * 修理费等其它费用(除税)
     */
    public void setExtaxRepair(java.math.BigDecimal extaxRepair) {
        this.extaxRepair = extaxRepair;
    }
    /**
     * 月度结算费用(含税)
     */
    public java.math.BigDecimal getIntaxMonthlySettlementAmount() {
        return intaxMonthlySettlementAmount;
    }

    /**
     * 月度结算费用(含税)
     */
    public void setIntaxMonthlySettlementAmount(java.math.BigDecimal intaxMonthlySettlementAmount) {
        this.intaxMonthlySettlementAmount = intaxMonthlySettlementAmount;
    }
    /**
     * 月度结算费用(除税)
     */
    public java.math.BigDecimal getExtaxMonthlySettlementAmount() {
        return extaxMonthlySettlementAmount;
    }

    /**
     * 月度结算费用(除税)
     */
    public void setExtaxMonthlySettlementAmount(java.math.BigDecimal extaxMonthlySettlementAmount) {
        this.extaxMonthlySettlementAmount = extaxMonthlySettlementAmount;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }


}
